can_attach_to

Function can_attach_to 

fn can_attach_to(
    world: &dyn LevelReader,
    pos: BlockPos,
    direction: Direction,
) -> bool
Returns whether a ladder can be placed on a particular face of a block located at a certain position.