fn can_attach_to(
world: &dyn LevelReader,
pos: BlockPos,
direction: Direction,
) -> boolExpand description
Returns whether a ladder can be placed on a particular face of a block located at a certain position.
fn can_attach_to(
world: &dyn LevelReader,
pos: BlockPos,
direction: Direction,
) -> boolReturns whether a ladder can be placed on a particular face of a block located at a certain position.